EXPORTS
	?IsDateTheSame@SchSvrHelpers@@SAHABVTTime@@0@Z @ 1 NONAME ; int SchSvrHelpers::IsDateTheSame(class TTime const &, class TTime const &)
	?IsItemRefTheSame@SchSvrHelpers@@SAHABVTSchedulerItemRef@@0@Z @ 2 NONAME ; int SchSvrHelpers::IsItemRefTheSame(class TSchedulerItemRef const &, class TSchedulerItemRef const &)
	?IsScheduleStateTheSame@SchSvrHelpers@@SAHABVTScheduleState@@0@Z @ 3 NONAME ; int SchSvrHelpers::IsScheduleStateTheSame(class TScheduleState const &, class TScheduleState const &)
	?IsTaskInfoTheSame@SchSvrHelpers@@SAHABVTTaskInfo@@0@Z @ 4 NONAME ; int SchSvrHelpers::IsTaskInfoTheSame(class TTaskInfo const &, class TTaskInfo const &)
	?IsTimeTheSame@SchSvrHelpers@@SAHABVTTime@@0@Z @ 5 NONAME ; int SchSvrHelpers::IsTimeTheSame(class TTime const &, class TTime const &)
	?Pause@SchSvrHelpers@@SAXAAVRTest@@H@Z @ 6 NONAME ; void SchSvrHelpers::Pause(class RTest &, int)
	?Rand@SchSvrHelpers@@SAHHHAA_J@Z @ 7 NONAME ; int SchSvrHelpers::Rand(int, int, class TInt64 &)
	?RandomScheduleEntryInfo@SchSvrHelpers@@SA?AVTScheduleEntryInfo@@AA_J@Z @ 8 NONAME ; class TScheduleEntryInfo SchSvrHelpers::RandomScheduleEntryInfo(class TInt64 &)
	?ScheduleEntryInfo@SchSvrHelpers@@SA?AVTScheduleEntryInfo@@W4TIntervalType@@ABVTTime@@HVTTimeIntervalMinutes@@@Z @ 9 NONAME ; class TScheduleEntryInfo SchSvrHelpers::ScheduleEntryInfo(enum TIntervalType, class TTime const &, int, class TTimeIntervalMinutes)
	?TaskInfo@SchSvrHelpers@@SA?AVTTaskInfo@@ABVTDesC16@@HH@Z @ 10 NONAME ; class TTaskInfo SchSvrHelpers::TaskInfo(class TDesC16 const &, int, int)
	?TimeBasedOnOffset@SchSvrHelpers@@SA?AVTDateTime@@HHHHHH@Z @ 11 NONAME ; class TDateTime SchSvrHelpers::TimeBasedOnOffset(int, int, int, int, int, int)
	?DeleteAllSchedulesL@SchSvrHelpers@@SAXAAVRScheduler@@@Z @ 12 NONAME ; void SchSvrHelpers::DeleteAllSchedulesL(class RScheduler &)
	?Close@STaskSemaphore@@QAEXXZ @ 13 NONAME ; void STaskSemaphore::Close(void)
	?CreateL@STaskSemaphore@@QAEXXZ @ 14 NONAME ; void STaskSemaphore::CreateL(void)
	?DeleteScheduleFilesL@SchSvrHelpers@@SAXXZ @ 15 NONAME ; void SchSvrHelpers::DeleteScheduleFilesL(void)
	?KillProcess@CleanupHelpers@@SAHABVTDesC16@@@Z @ 16 NONAME ; int CleanupHelpers::KillProcess(class TDesC16 const &)
	?RegisterClientL@SchSvrHelpers@@SAHAAVRScheduler@@@Z @ 17 NONAME ; int SchSvrHelpers::RegisterClientL(class RScheduler &)
	?TestCleanupL@CleanupHelpers@@SAXXZ @ 18 NONAME ; void CleanupHelpers::TestCleanupL(void)
	?WaitL@STaskSemaphore@@SAXXZ @ 19 NONAME ; void STaskSemaphore::WaitL(void)
	?WaitL@STaskSemaphore@@SAHH@Z @ 20 NONAME ; int STaskSemaphore::WaitL(int)
	?IsDateTheSame@SchSvrHelpers@@SAHABVTTsTime@@0@Z @ 21 NONAME ; int SchSvrHelpers::IsDateTheSame(class TTsTime const &, class TTsTime const &)
	?IsScheduleStateTheSame@SchSvrHelpers@@SAHABVTScheduleState2@@0@Z @ 22 NONAME ; int SchSvrHelpers::IsScheduleStateTheSame(class TScheduleState2 const &, class TScheduleState2 const &)
	?IsTimeTheSame@SchSvrHelpers@@SAHABVTTsTime@@0@Z @ 23 NONAME ; int SchSvrHelpers::IsTimeTheSame(class TTsTime const &, class TTsTime const &)
	?RandomScheduleEntryInfoHometime@SchSvrHelpers@@SA?AVTScheduleEntryInfo2@@AA_J@Z @ 24 NONAME ; class TScheduleEntryInfo2 SchSvrHelpers::RandomScheduleEntryInfoHometime(long long &)
	?RandomScheduleEntryInfoUtc@SchSvrHelpers@@SA?AVTScheduleEntryInfo2@@AA_J@Z @ 25 NONAME ; class TScheduleEntryInfo2 SchSvrHelpers::RandomScheduleEntryInfoUtc(long long &)
	?ScheduleEntryInfo@SchSvrHelpers@@SA?AVTScheduleEntryInfo2@@W4TIntervalType@@ABVTTsTime@@HVTTimeIntervalMinutes@@@Z @ 26 NONAME ; class TScheduleEntryInfo2 SchSvrHelpers::ScheduleEntryInfo(enum TIntervalType, class TTsTime const &, int, class TTimeIntervalMinutes)
	?Pause@SchSvrHelpers@@SAXH@Z @ 27 NONAME ; void SchSvrHelpers::Pause(int)
	?IsTimeTheSameNoSeconds@SchSvrHelpers@@SAHABVTTsTime@@0@Z @ 28 NONAME ; int SchSvrHelpers::IsTimeTheSameNoSeconds(class TTsTime const &, class TTsTime const &)
	?SetHomeTimeL@SchSvrHelpers@@SAHABVTTime@@@Z @ 29 NONAME ; int SchSvrHelpers::SetHomeTimeL(class TTime const &)
	?SetUTCTimeL@SchSvrHelpers@@SAHABVTTime@@@Z @ 30 NONAME ; int SchSvrHelpers::SetUTCTimeL(class TTime const &)
	?UtcTimeBasedOnOffset@SchSvrHelpers@@SA?AVTDateTime@@HHHHHH@Z @ 31 NONAME ; class TDateTime SchSvrHelpers::UtcTimeBasedOnOffset(int, int, int, int, int, int)
	?CheckTaskFilesL@SchSvrHelpers@@SAHXZ @ 32 NONAME ; int SchSvrHelpers::CheckTaskFilesL(void)
	?CreateTaskFilesL@SchSvrHelpers@@SAHXZ @ 33 NONAME ; int SchSvrHelpers::CreateTaskFilesL(void)
	?RegisterNonExistentClient@SchSvrHelpers@@SAHAAVRScheduler@@@Z @ 34 NONAME ; int SchSvrHelpers::RegisterNonExistentClient(class RScheduler &)
	?RegisterPanicingClient@SchSvrHelpers@@SAHAAVRScheduler@@@Z @ 35 NONAME ; int SchSvrHelpers::RegisterPanicingClient(class RScheduler &)
	?LaunchTaskSchedulerL@SchSvrHelpers@@SAHXZ @ 36 NONAME ; int SchSvrHelpers::LaunchTaskSchedulerL(void)
